# applications/skills

## administrative assistance

- allow NL queries of structured contact list information
- plugin for gmail/contacts/calendar to query all your email and contacts, etc

### difficult

- Implement calendly.com functionality with a conversational interface. Present views of someone else's calendar (any qary member who's shared their calendar) to a user and allow them to select a date/time/location for their meeting.
- Book a flight using airline apis?
- Book a restaurant/venue resurvation using booking.com or similar?
